(define-package "ghub" "0"
  "Minuscule client libraries for Git forge APIs."
  '((emacs "25.1")
    (let-alist "1.0.5")
    (treepy "0.1.1")))
